=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-10-22 07:16:38 +0000
+++ drizzled/drizzled.cc	2010-10-25 18:26:50 +0000
@@ -1531,7 +1531,7 @@
 
   if (item_create_init())
     return 1;
-  if (set_var_init())
+  if (sys_var_init())
     return 1;
   /* Creates static regex matching for temporal values */
   if (! init_temporal_formats())

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-10-23 21:00:18 +0000
+++ drizzled/include.am	2010-10-25 18:26:50 +0000
@@ -407,6 +407,7 @@
 			      drizzled/strfunc.h \
 			      drizzled/structs.h \
 			      drizzled/symbol_hash.h \
+			      drizzled/sys_var.h \
 			      drizzled/table.h \
 			      drizzled/table_function_container.h \
 			      drizzled/table_ident.h \
@@ -756,6 +757,7 @@
 				 drizzled/statement/update.cc \
 				 drizzled/status_helper.cc \
 				 drizzled/strfunc.cc \
+				 drizzled/sys_var.cc \
 				 drizzled/table.cc \
 				 drizzled/table_function_container.cc \
 				 drizzled/table_list.cc \

=== modified file 'drizzled/module/context.cc'
--- drizzled/module/context.cc	2010-10-15 20:18:02 +0000
+++ drizzled/module/context.cc	2010-10-25 18:26:50 +0000
@@ -22,7 +22,7 @@
 #include "drizzled/module/option_map.h"
 #include "drizzled/module/module.h"
 #include "drizzled/drizzled.h"
-#include "drizzled/set_var.h"
+#include "drizzled/sys_var.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/module/module.cc'
--- drizzled/module/module.cc	2010-10-18 18:22:32 +0000
+++ drizzled/module/module.cc	2010-10-25 18:26:50 +0000
@@ -22,7 +22,7 @@
 #include <algorithm>
 
 #include "drizzled/module/module.h"
-#include "drizzled/set_var.h"
+#include "drizzled/sys_var.h"
 #include "drizzled/util/functors.h"
 
 namespace drizzled

=== modified file 'drizzled/plugin.h'
--- drizzled/plugin.h	2010-10-07 14:55:42 +0000
+++ drizzled/plugin.h	2010-10-25 18:26:50 +0000
@@ -20,6 +20,9 @@
 #ifndef DRIZZLED_PLUGIN_H
 #define DRIZZLED_PLUGIN_H
 
+#include <boost/program_options.hpp>
+#include <boost/filesystem.hpp>
+
 #include "drizzled/module/manifest.h"
 #include "drizzled/module/module.h"
 #include "drizzled/plugin/version.h"
@@ -28,8 +31,6 @@
 
 #include "drizzled/lex_string.h"
 #include "drizzled/xid.h"
-#include <boost/program_options.hpp>
-#include <boost/filesystem.hpp>
 
 namespace drizzled
 {
@@ -106,6 +107,7 @@
 struct st_show_var_func_container {
   mysql_show_var_func func;
 };
+
 /*
   declarations for server variables and command line options
 */

=== modified file 'drizzled/select_dumpvar.h'
--- drizzled/select_dumpvar.h	2010-05-26 23:33:06 +0000
+++ drizzled/select_dumpvar.h	2010-10-25 18:26:50 +0000
@@ -21,7 +21,7 @@
 #define DRIZZLED_SELECT_DUMPVAR_H
 
 #include "drizzled/error.h"
-#include "drizzled/error.h"
+#include "drizzled/function/set_user_var.h"
 
 #include <vector>
 

=== added file 'drizzled/set_var.cc'
--- drizzled/set_var.cc	1970-01-01 00:00:00 +0000
+++ drizzled/set_var.cc	2010-10-25 18:26:50 +0000
@@ -0,0 +1,161 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "drizzled/session.h"
+#include "drizzled/sql_list.h"
+
+using namespace std;
+
+namespace drizzled
+{
+
+/**
+  Execute update of all variables.
+
+  First run a check of all variables that all updates will go ok.
+  If yes, then execute all updates, returning an error if any one failed.
+
+  This should ensure that in all normal cases none all or variables are
+  updated.
+
+  @param Session		Thread id
+  @param var_list       List of variables to update
+
+  @retval
+    0	ok
+  @retval
+    1	ERROR, message sent (normally no variables was updated)
+  @retval
+    -1  ERROR, message not sent
+*/
+
+int sql_set_variables(Session *session, List<set_var_base> *var_list)
+{
+  int error;
+  List_iterator_fast<set_var_base> it(*var_list);
+
+  set_var_base *var;
+  while ((var=it++))
+  {
+    if ((error= var->check(session)))
+      goto err;
+  }
+  if (!(error= test(session->is_error())))
+  {
+    it.rewind();
+    while ((var= it++))
+      error|= var->update(session);         // Returns 0, -1 or 1
+  }
+
+err:
+  free_underlaid_joins(session, &session->lex->select_lex);
+  return(error);
+}
+
+
+/*****************************************************************************
+  Functions to handle SET mysql_internal_variable=const_expr
+*****************************************************************************/
+
+int set_var::check(Session *session)
+{
+  if (var->is_readonly())
+  {
+    my_error(ER_INCORRECT_GLOBAL_LOCAL_VAR, MYF(0), var->getName().c_str(), "read only");
+    return -1;
+  }
+  if (var->check_type(type))
+  {
+    int err= type == OPT_GLOBAL ? ER_LOCAL_VARIABLE : ER_GLOBAL_VARIABLE;
+    my_error(err, MYF(0), var->getName().c_str());
+    return -1;
+  }
+  /* value is a NULL pointer if we are using SET ... = DEFAULT */
+  if (!value)
+  {
+    if (var->check_default(type))
+    {
+      my_error(ER_NO_DEFAULT, MYF(0), var->getName().c_str());
+      return -1;
+    }
+    return 0;
+  }
+
+  if ((!value->fixed &&
+       value->fix_fields(session, &value)) || value->check_cols(1))
+    return -1;
+  if (var->check_update_type(value->result_type()))
+  {
+    my_error(ER_WRONG_TYPE_FOR_VAR, MYF(0), var->getName().c_str());
+    return -1;
+  }
+  return var->check(session, this) ? -1 : 0;
+}
+
+/**
+  Update variable
+
+  @param   session    thread handler
+  @returns 0|1    ok or	ERROR
+
+  @note ERROR can be only due to abnormal operations involving
+  the server's execution evironment such as
+  out of memory, hard disk failure or the computer blows up.
+  Consider set_var::check() method if there is a need to return
+  an error due to logics.
+*/
+int set_var::update(Session *session)
+{
+  if (! value)
+    var->set_default(session, type);
+  else if (var->update(session, this))
+    return -1;				// should never happen
+  if (var->getAfterUpdateTrigger())
+    (*var->getAfterUpdateTrigger())(session, type);
+  return 0;
+}
+
+/*****************************************************************************
+  Functions to handle SET @user_variable=const_expr
+*****************************************************************************/
+
+int set_var_user::check(Session *session)
+{
+  /*
+    Item_func_set_user_var can't substitute something else on its place =>
+    0 can be passed as last argument (reference on item)
+  */
+  return (user_var_item->fix_fields(session, (Item**) 0) ||
+	  user_var_item->check(0)) ? -1 : 0;
+}
+
+
+int set_var_user::update(Session *)
+{
+  if (user_var_item->update())
+  {
+    /* Give an error if it's not given already */
+    my_message(ER_SET_CONSTANTS_ONLY, ER(ER_SET_CONSTANTS_ONLY), MYF(0));
+    return -1;
+  }
+  return 0;
+}
+
+} /* namespace drizzled */

=== added file 'drizzled/set_var.h'
--- drizzled/set_var.h	1970-01-01 00:00:00 +0000
+++ drizzled/set_var.h	2010-10-25 18:26:50 +0000
@@ -0,0 +1,115 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_SET_VAR_H
+#define DRIZZLED_SET_VAR_H
+
+#include "drizzled/function/func.h"
+#include "drizzled/function/set_user_var.h"
+#include "drizzled/item/string.h"
+#include "drizzled/item/field.h"
+
+namespace drizzled
+{
+
+class Time_zone;
+typedef struct my_locale_st MY_LOCALE;
+
+/* Classes to support the SET command */
+
+
+/****************************************************************************
+  Variables that are changable runtime are declared using the
+  following classes
+****************************************************************************/
+
+/****************************************************************************
+  Classes for parsing of the SET command
+****************************************************************************/
+
+class set_var_base :public memory::SqlAlloc
+{
+public:
+  set_var_base() {}
+  virtual ~set_var_base() {}
+  virtual int check(Session *session)=0;	/* To check privileges etc. */
+  virtual int update(Session *session)=0;	/* To set the value */
+  /* light check for PS */
+};
+
+/* MySQL internal variables */
+class set_var :public set_var_base
+{
+public:
+  sys_var *var;
+  Item *value;
+  sql_var_t type;
+  union
+  {
+    const CHARSET_INFO *charset;
+    uint32_t uint32_t_value;
+    uint64_t uint64_t_value;
+    size_t size_t_value;
+    plugin::StorageEngine *storage_engine;
+    Time_zone *time_zone;
+    MY_LOCALE *locale_value;
+  } save_result;
+  LEX_STRING base;			/* for structs */
+
+  set_var(sql_var_t type_arg, sys_var *var_arg,
+          const LEX_STRING *base_name_arg, Item *value_arg)
+    :var(var_arg), type(type_arg), base(*base_name_arg)
+  {
+    /*
+      If the set value is a field, change it to a string to allow things like
+      SET table_type=MYISAM;
+    */
+    if (value_arg && value_arg->type() == Item::FIELD_ITEM)
+    {
+      Item_field *item= (Item_field*) value_arg;
+      if (!(value=new Item_string(item->field_name,
+                  (uint32_t) strlen(item->field_name),
+				  item->collation.collation)))
+	value=value_arg;			/* Give error message later */
+    }
+    else
+      value=value_arg;
+  }
+  int check(Session *session);
+  int update(Session *session);
+};
+
+/* User variables like @my_own_variable */
+
+class set_var_user: public set_var_base
+{
+  Item_func_set_user_var *user_var_item;
+public:
+  set_var_user(Item_func_set_user_var *item)
+    :user_var_item(item)
+  {}
+  int check(Session *session);
+  int update(Session *session);
+};
+
+int sql_set_variables(Session *session, List<set_var_base> *var_list);
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_SET_VAR_H */

=== modified file 'drizzled/sql_lex.h'
--- drizzled/sql_lex.h	2010-10-16 23:41:19 +0000
+++ drizzled/sql_lex.h	2010-10-25 18:26:50 +0000
@@ -62,7 +62,8 @@
 */
 
 #ifdef DRIZZLE_SERVER
-# include <drizzled/set_var.h>
+/* set_var should change to set_var here ... */
+# include <drizzled/sys_var.h>
 # include <drizzled/item/func.h>
 # ifdef DRIZZLE_YACC
 #  define LEX_YYSTYPE void *

=== modified file 'drizzled/status_helper.cc'
--- drizzled/status_helper.cc	2010-10-14 18:58:48 +0000
+++ drizzled/status_helper.cc	2010-10-25 18:26:50 +0000
@@ -27,9 +27,14 @@
 
 #include <sstream>
 
-using namespace drizzled;
 using namespace std;
 
+namespace drizzled
+{
+
+extern time_t server_start_time;
+extern time_t flush_status_time;
+
 static int show_starttime_new(drizzle_show_var *var, char *buff)
 {
   var->type= SHOW_LONG;
@@ -168,3 +173,5 @@
   {"Uptime_since_flush_status", (char*) &show_flushstatustime_cont_new,   SHOW_FUNC},
   {NULL, NULL, SHOW_LONGLONG}
 };
+
+} /* namespace drizzled */

=== renamed file 'drizzled/set_var.cc' => 'drizzled/sys_var.cc'
--- drizzled/set_var.cc	2010-10-19 21:51:42 +0000
+++ drizzled/sys_var.cc	2010-10-25 18:26:50 +0000
@@ -1548,14 +1548,14 @@
   Initialize the system variables
 
   SYNOPSIS
-    set_var_init()
+    sys_var_init()
 
   RETURN VALUES
     0           SUCCESS
     otherwise   FAILURE
 */
 
-int set_var_init()
+int sys_var_init()
 {
   try
   {
@@ -1686,138 +1686,6 @@
 }
 
 
-/**
-  Execute update of all variables.
-
-  First run a check of all variables that all updates will go ok.
-  If yes, then execute all updates, returning an error if any one failed.
-
-  This should ensure that in all normal cases none all or variables are
-  updated.
-
-  @param Session		Thread id
-  @param var_list       List of variables to update
-
-  @retval
-    0	ok
-  @retval
-    1	ERROR, message sent (normally no variables was updated)
-  @retval
-    -1  ERROR, message not sent
-*/
-
-int sql_set_variables(Session *session, List<set_var_base> *var_list)
-{
-  int error;
-  List_iterator_fast<set_var_base> it(*var_list);
-
-  set_var_base *var;
-  while ((var=it++))
-  {
-    if ((error= var->check(session)))
-      goto err;
-  }
-  if (!(error= test(session->is_error())))
-  {
-    it.rewind();
-    while ((var= it++))
-      error|= var->update(session);         // Returns 0, -1 or 1
-  }
-
-err:
-  free_underlaid_joins(session, &session->lex->select_lex);
-  return(error);
-}
-
-
-/*****************************************************************************
-  Functions to handle SET mysql_internal_variable=const_expr
-*****************************************************************************/
-
-int set_var::check(Session *session)
-{
-  if (var->is_readonly())
-  {
-    my_error(ER_INCORRECT_GLOBAL_LOCAL_VAR, MYF(0), var->getName().c_str(), "read only");
-    return -1;
-  }
-  if (var->check_type(type))
-  {
-    int err= type == OPT_GLOBAL ? ER_LOCAL_VARIABLE : ER_GLOBAL_VARIABLE;
-    my_error(err, MYF(0), var->getName().c_str());
-    return -1;
-  }
-  /* value is a NULL pointer if we are using SET ... = DEFAULT */
-  if (!value)
-  {
-    if (var->check_default(type))
-    {
-      my_error(ER_NO_DEFAULT, MYF(0), var->getName().c_str());
-      return -1;
-    }
-    return 0;
-  }
-
-  if ((!value->fixed &&
-       value->fix_fields(session, &value)) || value->check_cols(1))
-    return -1;
-  if (var->check_update_type(value->result_type()))
-  {
-    my_error(ER_WRONG_TYPE_FOR_VAR, MYF(0), var->getName().c_str());
-    return -1;
-  }
-  return var->check(session, this) ? -1 : 0;
-}
-
-/**
-  Update variable
-
-  @param   session    thread handler
-  @returns 0|1    ok or	ERROR
-
-  @note ERROR can be only due to abnormal operations involving
-  the server's execution evironment such as
-  out of memory, hard disk failure or the computer blows up.
-  Consider set_var::check() method if there is a need to return
-  an error due to logics.
-*/
-int set_var::update(Session *session)
-{
-  if (! value)
-    var->set_default(session, type);
-  else if (var->update(session, this))
-    return -1;				// should never happen
-  if (var->getAfterUpdateTrigger())
-    (*var->getAfterUpdateTrigger())(session, type);
-  return 0;
-}
-
-/*****************************************************************************
-  Functions to handle SET @user_variable=const_expr
-*****************************************************************************/
-
-int set_var_user::check(Session *session)
-{
-  /*
-    Item_func_set_user_var can't substitute something else on its place =>
-    0 can be passed as last argument (reference on item)
-  */
-  return (user_var_item->fix_fields(session, (Item**) 0) ||
-	  user_var_item->check(0)) ? -1 : 0;
-}
-
-
-int set_var_user::update(Session *)
-{
-  if (user_var_item->update())
-  {
-    /* Give an error if it's not given already */
-    my_message(ER_SET_CONSTANTS_ONLY, ER(ER_SET_CONSTANTS_ONLY), MYF(0));
-    return -1;
-  }
-  return 0;
-}
-
 /****************************************************************************
  Functions to handle table_type
 ****************************************************************************/

=== renamed file 'drizzled/set_var.h' => 'drizzled/sys_var.h'
--- drizzled/set_var.h	2010-10-22 00:12:47 +0000
+++ drizzled/sys_var.h	2010-10-25 18:26:50 +0000
@@ -17,8 +17,8 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_SET_VAR_H
-#define DRIZZLED_SET_VAR_H
+#ifndef DRIZZLED_SYS_VAR_H
+#define DRIZZLED_SYS_VAR_H
 
 #include <string>
 #include <boost/filesystem.hpp>
@@ -28,20 +28,12 @@
 #include "drizzled/item/string.h"
 #include "drizzled/item/field.h"
 #include "drizzled/constrained_value.h"
+#include "drizzled/set_var.h"
 
 namespace drizzled
 {
 
-/* Classes to support the SET command */
-
-
-/****************************************************************************
-  Variables that are changable runtime are declared using the
-  following classes
-****************************************************************************/
-
 class sys_var;
-class set_var;
 class sys_var_pluginvar; /* opaque */
 class Time_zone;
 typedef struct my_locale_st MY_LOCALE;
@@ -70,8 +62,6 @@
 extern char system_time_zone[30];
 extern char *opt_tc_log_file;
 extern uint64_t session_startup_options;
-extern time_t server_start_time;
-extern time_t flush_status_time;
 extern uint32_t global_thread_id;
 extern uint64_t table_cache_size;
 extern uint64_t max_connect_errors;
@@ -88,64 +78,7 @@
 
 uint64_t fix_unsigned(Session *, uint64_t, const struct option *);
 
-void init_sys_var();
-
-/****************************************************************************
-  Classes for parsing of the SET command
-****************************************************************************/
-
-class set_var_base :public memory::SqlAlloc
-{
-public:
-  set_var_base() {}
-  virtual ~set_var_base() {}
-  virtual int check(Session *session)=0;	/* To check privileges etc. */
-  virtual int update(Session *session)=0;	/* To set the value */
-  /* light check for PS */
-};
-
-/* MySQL internal variables */
-class set_var :public set_var_base
-{
-public:
-  sys_var *var;
-  Item *value;
-  sql_var_t type;
-  union
-  {
-    const CHARSET_INFO *charset;
-    uint32_t uint32_t_value;
-    uint64_t uint64_t_value;
-    size_t size_t_value;
-    plugin::StorageEngine *storage_engine;
-    Time_zone *time_zone;
-    MY_LOCALE *locale_value;
-  } save_result;
-  LEX_STRING base;			/* for structs */
-
-  set_var(sql_var_t type_arg, sys_var *var_arg,
-          const LEX_STRING *base_name_arg, Item *value_arg)
-    :var(var_arg), type(type_arg), base(*base_name_arg)
-  {
-    /*
-      If the set value is a field, change it to a string to allow things like
-      SET table_type=MYISAM;
-    */
-    if (value_arg && value_arg->type() == Item::FIELD_ITEM)
-    {
-      Item_field *item= (Item_field*) value_arg;
-      if (!(value=new Item_string(item->field_name,
-                  (uint32_t) strlen(item->field_name),
-				  item->collation.collation)))
-	value=value_arg;			/* Give error message later */
-    }
-    else
-      value=value_arg;
-  }
-  int check(Session *session);
-  int update(Session *session);
-};
-
+int sys_var_init();
 
 /**
  * A class which represents a variable, either global or 
@@ -156,7 +89,7 @@
 protected:
   std::string name; /**< The name of the variable */
   sys_after_update_func after_update; /**< Function pointer triggered after the variable's value is updated */
-  struct option *option_limits; /**< Updated by by set_var_init() */
+  struct option *option_limits; /**< Updated by by sys_var_init() */
   bool m_allow_empty_value; /**< Does variable allow an empty value? */
 public:
   sys_var(const std::string name_arg, sys_after_update_func func= NULL)
@@ -1086,19 +1019,6 @@
 };
 
 
-/* User variables like @my_own_variable */
-
-class set_var_user: public set_var_base
-{
-  Item_func_set_user_var *user_var_item;
-public:
-  set_var_user(Item_func_set_user_var *item)
-    :user_var_item(item)
-  {}
-  int check(Session *session);
-  int update(Session *session);
-};
-
 
 /* For sql_yacc */
 struct sys_var_with_base
@@ -1111,14 +1031,12 @@
   Prototypes for helper functions
 */
 
-int set_var_init();
 drizzle_show_var* enumerate_sys_vars(Session *session);
 void drizzle_add_plugin_sysvar(sys_var_pluginvar *var);
 void drizzle_del_plugin_sysvar();
 void add_sys_var_to_list(sys_var *var, struct option *long_options);
 void add_sys_var_to_list(sys_var *var);
 sys_var *find_sys_var(Session *session, const char *str, uint32_t length=0);
-int sql_set_variables(Session *session, List<set_var_base> *var_list);
 bool not_all_support_one_shot(List<set_var_base> *var_list);
 extern sys_var_session_time_zone sys_time_zone;
 extern sys_var_session_bit sys_autocommit;
@@ -1128,4 +1046,4 @@
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_SET_VAR_H */
+#endif /* DRIZZLED_SYS_VAR_H */

=== modified file 'plugin/auth_file/auth_file.cc'
--- plugin/auth_file/auth_file.cc	2010-10-17 14:38:50 +0000
+++ plugin/auth_file/auth_file.cc	2010-10-25 18:26:50 +0000
@@ -22,16 +22,17 @@
 #include <fstream>
 #include <map>
 #include <string>
+#include <iostream>
+
+#include <boost/program_options.hpp>
 
 #include "drizzled/configmake.h"
 #include "drizzled/plugin/authentication.h"
 #include "drizzled/security_context.h"
 #include "drizzled/util/convert.h"
 #include "drizzled/algorithm/sha1.h"
-#include <boost/program_options.hpp>
-#include <drizzled/module/option_map.h>
-#include <drizzled/set_var.h>
-#include <iostream>
+#include "drizzled/module/option_map.h"
+#include "drizzled/sys_var.h"
 
 namespace po= boost::program_options;
 using namespace std;

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2010-10-14 18:58:48 +0000
+++ po/POTFILES.in	2010-10-25 18:26:50 +0000
@@ -48,6 +48,7 @@
 drizzled/sql_table.cc
 drizzled/sql_yacc.cc
 drizzled/statement/alter_table.cc
+drizzled/sys_var.cc
 drizzled/table.cc
 drizzled/table_share.cc
 drizzled/transaction_services.cc

